### Name: ScottKnott-package
### Title: The ScottKnott Clustering Algoritm
### Aliases: ScottKnott-package ScottKnott
### Keywords: package htest univar tree design

### ** Examples

  ##
  ## Examples: Completely Randomized Design (CRD)
  ##
  ## Generating data
  x <- gl(4, 6, labels=LETTERS[1:4])
  r <- factor(rep(1:6, 4))
  y <- c(58, 49, 51, 56, 50, 48,
         60, 55, 66, 61, 54, 61,
         59, 47, 44, 49, 62, 60,
         45, 33, 34, 48, 42, 44)
  dm  <- data.frame(x, r) # Design matrix (a data.frame object)
  dfm <- data.frame(dm, y)

  ## PARAMETERS ARE ATOMIC VECTORS, DESIGN MATRIX AND THE RESPONSE VARIABLE
  ## From atomics 'x' and 'y'
  sk1 <- SK(x=x, y=y, model='y ~ x', which='x')
  summary(sk1)
  #plot(sk1, title='Treatments', col=rainbow(1)) # will not work
  plot(sk1, title='Treatments', col=rainbow(2))

  ## From design matrix (dm) and response variable (y)
  sk2 <- SK(x=dm, y=y, model='y ~ x', which='x')
  summary(sk2)
  plot(sk2, title='Treatments', xlab='Groups', ylab='Groups means')

  ## PARAMETER IS DATA.FRAME
  ## From data.frame (dfm)
  sk3 <- SK(x=dfm, model='y ~ x', which='x')
  summary(sk3)
  plot(sk3, title='Treatments', col=cm.colors(2))

  ## PARAMETER IS AOV
  sk4 <- SK(x=aov(y ~ x, data=dfm), which='x')
  summary(sk4)
  plot(sk4, title='Treatments')
  

  ##
  ## Example: Randomized Complete Block Design (RCBD)
  ##
  ## Generating data
  y <- c(142.36, 144.78, 145.19, 138.88,
         139.28, 137.77, 144.44, 130.61,
         140.73, 134.06, 136.07, 144.11,
         150.88, 135.83, 136.97, 136.36,
         153.49, 165.02, 151.75, 150.22)
  tra <- gl(5, 4, labels=LETTERS[1:5])
  blk <- factor(rep(1:4, 5))
  dm  <- data.frame(tra, blk) # Design matrix (a data.frame object)
  dfm <- data.frame(dm, y)

  ## PARAMETERS ARE DESIGN MATRIX AND THE RESPONSE VARIABLE
  ## From design matrix (dm) and response variable (y)
  sk1 <- SK(x=dm, y=y, model='y ~ blk + tra', which = 'tra')
  summary(sk1)
  plot(sk1)

  ## PARAMETER IS DATA.FRAME
  ## From data.frame (dfm)
  sk2 <- SK(x=dfm, model='y ~ blk + tra', which='tra')
  summary(sk2)
  plot(sk2, title='Treatments')

  ## which='blk'
  sk3 <- SK(x=dfm, model='y ~ blk + tra', which='blk')
  summary(sk3)
  plot(sk3, title='Blocks')

  ## PARAMETER IS AOV
  ## Doing a previous ANOVA
  av1 <- aov(y ~ blk + tra, data=dfm)
  summary(av1)

  ## From aov, which='blk' implicit
  sk4 <- SK(x=av1)
  summary(sk4)
  plot(sk4, title='Blocks')

  ## From aov, which='blk' explicit
  sk6 <- SK(x=av1, which='blk')
  summary(sk6)
  plot(sk6,title='Blocks')

  ## From aov, which='tra' explicit
  sk5 <- SK(x=av1, which='tra')
  summary(sk5)
  plot(sk5, title='Treatments')

  ##
  ## Example: Latin Squares Design (LSD)
  ##
  ## Generating data
  y <- c(518, 524, 420, 486, 515,
         458, 550, 384, 494, 318,
         583, 724, 556, 501, 660,
         432, 400, 297, 500, 438,
         331, 478, 489, 313, 394)
  tra  <- gl(5, 5, labels=LETTERS[1:5])
  rows <- factor(rep(1:5, 5))
  cols <- factor(c(2, 3, 5, 4, 1,
                   3, 4, 2, 1, 5,
                   4, 1, 3, 5, 2,
                   1, 5, 4, 2, 3,
                   5, 2, 1, 3, 4))
  dm  <- data.frame(tra, rows, cols) # Design matrix (a data.frame object)
  dfm <- data.frame(dm, y)

  ## PARAMETERS ARE DESIGN MATRIX AND THE RESPONSE VARIABLE
  ## From design matrix (dm) and response variable (y)
  sk1 <- SK(x=dm, y=y, model='y ~ rows + cols + tra', which='tra')
  summary(sk1)
  plot(sk1)

  ## PARAMETER IS DATA.FRAME
  ## From data.frame
  sk2 <- SK(x=dfm, model='y ~ rows + cols + tra', which='tra')
  summary(sk2)
  plot(sk2, title='Treatments')

  ## PARAMETER IS AOV
  ## Doing a previous ANOVA
  av1 <- aov(y ~ rows + cols + tra, data=dfm)
  summary(av1)

  ## From aov object, sig.level=5
  sk3 <- SK(av1, which='tra')
  summary(sk3)
  plot(sk5, title='Treatments, sig.level=.05')

  ## From aov object, sig.level=8
  sk4 <- SK(av1, which='tra', sig.level=.08)
  summary(sk4)
  plot(sk4, title='Treatments, sig.level=.08')



